@@ -32,7 +32,7 @@ from flask.ext.admin.babel import gettext, lazy_gettext
 
 from werkzeug import secure_filename
 
-from flask_login import login_required
+from flask_login import login_required, current_user, logout_user
 
 from field import *
 
@@ -52,6 +52,8 @@ def issubmodel(cls, name):
         return True
     return False
 
+from ..user.form import *
+
 class DashboardView(AdminIndexView):
     widgets = []
 
@@ -67,7 +69,7 @@ class DashboardView(AdminIndexView):
     	else:
     		return render_template("shelf/login/login.html", form=LoginForm(request.form))
 
-    @expose('/signup/', methods=("GET", "POST"))
+    '''@expose('/signup/', methods=("GET", "POST"))
     def signup(self):
         if validate_register_on_submit(request.form):
             return redirect(request.args.get("next") or url_for("admin.signin"))
@@ -79,18 +81,31 @@ class DashboardView(AdminIndexView):
         if validate_recover_on_submit(request.form):
             return redirect(request.args.get("next") or url_for("admin.signin"))
         else:
-    	   return render_template("shelf/login/recover.html", form=RecoverForm(request.form))
+    	   return render_template("shelf/login/recover.html", form=RecoverForm(request.form))'''
+
+    @expose('/logout/', methods=("GET",))
+    @login_required
+    def logout(self):
+        logout_user()
+        return redirect(request.args.get("next") or url_for("admin.signin"))
 
     @expose()
+    @login_required
     def index(self):
-        print self.widgets
-        return self.render(self._template, widgets=[w.render() for w in self.widgets])
+        return self.render(self._template, user=current_user, widgets=[w.render() for w in self.widgets])
 
 class ShelfModelView(sqla.ModelView):
     list_template = "shelf/model/list.html"
     create_template = "shelf/model/create.html"
     edit_template = "shelf/model/edit.html"
 
+    def create_blueprint(self, admin):
+        bp = super(ShelfModelView, self).create_blueprint(admin)
+        @bp.context_processor
+        def add_user():
+            return dict(user=current_user)
+        return bp
+
     def _order_by(self, query, joins, sort_field, sort_desc):
         """
             Apply order_by to the query
@@ -222,10 +237,12 @@ class ShelfModelView(sqla.ModelView):
             flash(gettext('Failed to delete models. %(error)s', error=str(ex)), 'error')
 
     @expose('/')
+    @login_required
     def index_view(self):
         return super(ShelfModelView, self).index_view()
 
     @expose('/new/', methods=('GET', 'POST'))
+    @login_required
     def create_view(self):
         """
             Create model view
@@ -255,6 +272,7 @@ class ShelfModelView(sqla.ModelView):
 
     
     @expose('/edit/', methods=('GET', 'POST'))
+    @login_required
     def edit_view(self):
         """
             Edit model view
@@ -322,7 +340,15 @@ class Library(fileadmin.FileAdmin):
     modal_list_template = "shelf/library/modal-list.html"
     modal_iconic_template = "shelf/library/modal-iconic.html"
 
+    def create_blueprint(self, admin):
+        bp = super(Library, self).create_blueprint(admin)
+        @bp.context_processor
+        def add_user():
+            return dict(user=current_user)
+        return bp
+
     @expose('/asyncupload', methods=("POST",))
+    @login_required
     def async_upload(self):
         mfile = request.form['file']
         mname = request.form['name']
@@ -364,6 +390,7 @@ class Library(fileadmin.FileAdmin):
 
 
     @expose('/delete/', methods=('POST',))
+    @login_required
     def delete(self):
         """
             Delete view method
@@ -409,6 +436,7 @@ class Library(fileadmin.FileAdmin):
 
     @expose('/mkdir/', methods=('GET', 'POST'))
     @expose('/mkdir/<path:path>', methods=('GET', 'POST'))
+    @login_required
     def mkdir(self, path=None):
         """
             Directory creation view method
@@ -444,6 +472,7 @@ class Library(fileadmin.FileAdmin):
 
 
     @expose('/rename/', methods=('GET', 'POST'))
+    @login_required
     def rename(self):
         """
             Rename view method
@@ -494,6 +523,7 @@ class Library(fileadmin.FileAdmin):
 
     @expose('/upload/', methods=('GET', 'POST'))
     @expose('/upload/<path:path>', methods=('GET', 'POST'))
+    @login_required
     def upload(self, path=None):
         """
             Upload view method
@@ -551,6 +581,7 @@ class Library(fileadmin.FileAdmin):
 
     @expose('/modal-icons/')
     @expose('/modal-icons/b/<path:path>')
+    @login_required
     def modal_iconic_index(self, path=None):
         """
             Index view method
@@ -622,6 +653,7 @@ class Library(fileadmin.FileAdmin):
 
     @expose('/modal/')
     @expose('/modal/b/<path:path>')
+    @login_required
     def modal_index(self, path=None):
         """
             Index view method
@@ -693,6 +725,7 @@ class Library(fileadmin.FileAdmin):
 
     @expose('/icons/')
     @expose('/icons/b/<path:path>')
+    @login_required
     def iconic_index(self, path=None):
         """
             Index view method
@@ -764,6 +797,7 @@ class Library(fileadmin.FileAdmin):
 
     @expose('/')
     @expose('/b/<path:path>')
+    @login_required
     def index(self, path=None):
         """
             Index view method
